TextExt

Trait TextExt 

pub trait TextExt: TextExtError {
    // Required method
    fn get_all_text<'life0, 'async_trait>(
        &'life0 self,
    ) -> Pin<Box<dyn Future<Output = Result<String, <Self as TextExtError>::Error>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
}

Required Methods

fn get_all_text<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = Result<String, <Self as TextExtError>::Error>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Gets the full text within the accessible item.

Errors

This may fail based on the implementation of Text::get_text or TextBlocking::get_text. With the TextProxy and TextProxyBlocking implmentations, this can fail if you ask for an invalid start or end index, or if the DBus method fails to send or receive.

Implementors