pub trait Convertable {
Show 31 associated items
type Error: Error;
type Accessible: Accessible + Send + Sync;
type Action: Action + Send + Sync;
type Application: Application + Send + Sync;
type Collection: Collection + Send + Sync;
type Component: Component + Send + Sync;
type Document: Document + Send + Sync;
type Hypertext: Hypertext + Send + Sync;
type Hyperlink: Hyperlink + Send + Sync;
type Image: Image + Send + Sync;
type Selection: Selection + Send + Sync;
type Table: Table + Send + Sync;
type TableCell: TableCell + Send + Sync;
type Text: Text + Send + Sync;
type EditableText: EditableText + Send + Sync;
type Value: Value + Send + Sync;
// Required methods
fn to_accessible<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Self::Accessible, Self::Error>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn to_action<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Self::Action, Self::Error>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn to_application<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Self::Application, Self::Error>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn to_collection<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Self::Collection, Self::Error>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn to_component<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Self::Component, Self::Error>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn to_document<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Self::Document, Self::Error>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn to_hypertext<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Self::Hypertext, Self::Error>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn to_hyperlink<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Self::Hyperlink, Self::Error>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn to_image<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Self::Image, Self::Error>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn to_selection<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Self::Selection, Self::Error>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn to_table<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Self::Table, Self::Error>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn to_table_cell<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Self::TableCell, Self::Error>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn to_text<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Self::Text, Self::Error>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn to_editable_text<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Self::EditableText, Self::Error>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn to_value<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Self::Value, Self::Error>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
}Required Associated Types
type Error: Error
type Accessible: Accessible + Send + Sync
type Action: Action + Send + Sync
type Application: Application + Send + Sync
type Collection: Collection + Send + Sync
type Component: Component + Send + Sync
type Document: Document + Send + Sync
type Hypertext: Hypertext + Send + Sync
type Hyperlink: Hyperlink + Send + Sync
type Image: Image + Send + Sync
type Selection: Selection + Send + Sync
type Table: Table + Send + Sync
type TableCell: TableCell + Send + Sync
type Text: Text + Send + Sync
type EditableText: EditableText + Send + Sync
type Value: Value + Send + Sync
Required Methods
Sourcefn to_accessible<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Self::Accessible, Self::Error>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn to_accessible<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Self::Accessible, Self::Error>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Creates an Self::Accessible from the existing accessible item.
Errors
This may fail based on the implementation of.
Generally, it fails if the accessible item does not implement to accessible interface.
This shouldn’t be possible, but this function may fail for other reasons.
For example, to convert a zbus::Proxy into a Self::Accessible, it may fail to create the new atspi_proxies::accessible::AccessibleProxy.
Sourcefn to_action<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Self::Action, Self::Error>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn to_action<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Self::Action, Self::Error>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Creates an Self::Action from the existing accessible item.
Errors
This may fail based on the implementation. Generally, it fails if the accessible item does not implement to action interface.
Sourcefn to_application<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Self::Application, Self::Error>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn to_application<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Self::Application, Self::Error>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Creates an Self::Application from the existing accessible item.
Errors
This may fail based on the implementation. Generally, it fails if the accessible item does not implement to application interface.
Sourcefn to_collection<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Self::Collection, Self::Error>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn to_collection<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Self::Collection, Self::Error>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Creates an Self::Collection from the existing accessible item.
Errors
This may fail based on the implementation. Generally, it fails if the accessible item does not implement to collection interface.
Sourcefn to_component<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Self::Component, Self::Error>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn to_component<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Self::Component, Self::Error>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Creates an Self::Component from the existing accessible item.
Errors
This may fail based on the implementation. Generally, it fails if the accessible item does not implement to component interface.